@@ -23,10 +23,14 @@ Boggle board.
 
 Note that this module contains the following structures:
 
+* defaultOldDice16: a list of list of strings representing the 16 default
+                    dice in the original 4x4 Boggle board.
 * defaultDice16: a list of lists of strings representing the 16 default dice
                  in a standard 4x4 Boggle board.
 * defaultDice25: a list of lists of strings representing the 25 default dice
                  in a standard 5x5 Big Boggle board.
+* defaultChallengeDie: a list of strings representing the default special
+                       challenge die in some versions of Boggle.
 * Trie class: a class representing a trie, which the BoggleBoard findWords
               method uses in order to locate valid words in a Boggle board.
               Note that a word list based on YAWL:
@@ -71,6 +75,26 @@ import sys
 import random
 
 
+# The old dice used by original Boggle in a 4x4 grid.
+defaultOldDice16 = [
+    ['a', 'a', 'c', 'i', 'o', 't'],
+    ['a', 'h', 'm', 'o', 'r', 's'],
+    ['e', 'g', 'k', 'l', 'u', 'y'],
+    ['a', 'b', 'i', 'l', 't', 'y'],
+    ['a', 'c', 'd', 'e', 'm', 'p'],
+    ['e', 'g', 'i', 'n', 't', 'v'],
+    ['g', 'i', 'l', 'r', 'u', 'w'],
+    ['e', 'l', 'p', 's', 't', 'u'],
+    ['d', 'e', 'n', 'o', 's', 'w'],
+    ['a', 'c', 'e', 'l', 'r', 's'],
+    ['a', 'b', 'j', 'm', 'o', 'qu'],
+    ['e', 'e,' 'f', 'h', 'i', 'y'],
+    ['e', 'h', 'i', 'n', 'p', 's'],
+    ['d', 'k', 'n', 'o', 't', 'u'],
+    ['a', 'd', 'e', 'n', 'v', 'z'],
+    ['b', 'i', 'f', 'o', 'r', 'x']
+]
+
 # The default dice used by Boggle in a 4x4 grid.
 defaultDice16 = [
     ['e', 'l', 'r', 't', 't', 'y'],
@@ -120,13 +144,10 @@ defaultDice25 = [
     ['o', 'o', 'o', 't', 't', 'u']
 ]
 
-# The additional challenge die in Big Boggle. This can be substituted in for one
-# of the above, or added to the above, in which case, one die will be omitted
+# The additional challenge die in some versions. This can be substituted in for
+# one of the above, or added to the above, in which case, one die will be omitted
 # randomly.
-defaultDie25Challenge = ['i', 'k', 'l', 'm', 'qu', 'u']
-
-# The collection of all dice in a 5x5 Big Boggle game, for convenience:
-defaultDice25Challenge = defaultDice25 + [defaultDie25Challenge]
+defaultChallengeDie = ['i', 'k', 'l', 'm', 'qu', 'u']
 
 # The default tiles used in a Scrabble game, minus the blanks.
 defaultTiles = ['a']*9 + ['b']*2 + ['c']*2 + ['d']*4 + ['e']*11 + ['f']*2 + ['g']*3 + ['h']*2 + ['i']*8 + ['l']*4 + ['m']*2 + ['n']*6 + ['o']*8 + ['p']*2 + ['r']*6 + ['s']*4 + ['t']*6 + ['u']*4 + ['v']*2 + ['w']*2 + ['y']*2 + ['j','k','q','x','z']
